json_to_ui library
Classes
- HiveService
- JsonNetworkUiBuilder
- NetworkRequest
- This class is responsible for defining the configuration of a network request.
- NetworkService
- A service class to handle network operations such as GET and POST requests.
- UIBuilder
Enums
- Method
- An enumeration representing HTTP methods used for network requests.